{
  # config,
  pkgs,
  ...
}: {
  imports = [
    # Include the results of the hardware scan.
    ./hardware-configuration.nix
  ];

  # ------------ System ------------

  boot.loader.grub.extraEntries = ''
    menuentry "Void" {
      search --set=void --fs-uuid 987518fa-8ea0-49a6-b1e5-1fed4e4ae50f
      configfile "($void)/boot/grub/grub.cfg"
    }
  '';

  time.timeZone = "America/New_York";

  networking.hostName = "JWST";

  # This value determines the NixOS release from which the default
  # settings for stateful data, like file locations and database versions
  # on your system were taken. It's perfectly fine and recommended to leave
  # this value at the release version of the first install of this system.
  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "23.05"; # Did you read the comment?

  # ------------ Graphics ------------

  hardware.opengl.extraPackages = with pkgs; [
    intel-compute-runtime
    vaapiVdpau
  ];

  hardware.nvidia = {
    modesetting.enable = true;
    powerManagement.enable = false;
    powerManagement.finegrained = false;
    open = false;
    nvidiaSettings = true;
    prime = {
      offload.enable = true;
      offload.enableOffloadCmd = true;
      intelBusId = "PCI:0:2:0";
      nvidiaBusId = "PCI:1:0:0";
    };
  };

  services.xserver.videoDrivers = ["nvidia"];
}
